/*****************************************************************************/
/* LINKER SCRIPT                                                             */
/*                                                                           */
/* TARGET: RAM MEMORY                                                        */
/* CPU:    LPC2148                                                           */
/* LANG :  C                                                                 */
/*                                                                           */
/* NO SUPORT FOR ISP AND IAP (bootloader memory area)                        */
/*                                                                           */
/*****************************************************************************/

/* identify the Entry Point  */
ENTRY(_start)

/* specify the LPC2148 memory areas  */
MEMORY 
{
  flash   : ORIGIN = 0x00000000, LENGTH = 500K  /* free FLASH area */
  ram	    : ORIGIN = 0x40000000, LENGTH = 32K   /* free RAM area   */
  ram_usb : ORIGIN = 0x7FD00000, LENGTH = 8K    /* free RAM area   */
}

/* define stack end*/
_stack_end = ORIGIN(ram) + LENGTH(ram) - 4;

/* Section Definitions */
SECTIONS
{
  /* first section is .text which is used for code */
  .text :
  {
    *crt0.o (.text)            /* Startup code */
    *(.text)                   /* remaining code */
    *(.rodata)                 /* read-only data (constants) */
    *(.rodata*)
    *(.glue_7)                 /* libc suport */
    *(.glue_7t)                /* libc suport */
  } > ram

  . = ALIGN(4);
  _etext = . ;
  PROVIDE (etext = .);

  /* .data section which is used for initialized data */
  .data :
  {
    _data = .;
    *(.data)
  } > ram

  . = ALIGN(4);
  _edata = . ;
  PROVIDE (edata = .);

  /* .bss section which is used for uninitialized data */
  .bss (NOLOAD) :
  {
    __bss_start = . ;
    __bss_start__ = . ;
    *(.bss)
    *(COMMON)
    . = ALIGN(4);
  } > ram

  . = ALIGN(4);
  __bss_end__ = . ;
  PROVIDE (__bss_end = .);

  _end = . ;
  PROVIDE (end = .);
}
